@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -33,8 +33,7 @@ class QItemSelectionModel;
 class QLabel;
 class QRadioButton;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Collection;
 class CollectionComboBox;
 }
@@ -44,8 +43,7 @@ class CollectionComboBox;
  *
  * @author Tobias Koenig <tokoe@kde.org>
  */
-namespace KAddressBookImportExport
-{
+namespace KAddressBookImportExport {
 class KADDRESSBOOK_IMPORTEXPORT_EXPORT KAddressBookContactSelectionWidget : public QWidget
 {
     Q_OBJECT
@@ -87,15 +85,15 @@ private:
     Akonadi::Item::List collectSelectedItems() const;
     Akonadi::Item::List collectAddressBookItems() const;
 
-    QItemSelectionModel *mSelectionModel;
+    QItemSelectionModel *mSelectionModel = nullptr;
 
-    QLabel *mMessageLabel;
-    QRadioButton *mAllContactsButton;
-    QRadioButton *mSelectedContactsButton;
-    QRadioButton *mAddressBookContactsButton;
-    Akonadi::CollectionComboBox *mAddressBookSelection;
-    QCheckBox *mAddressBookSelectionRecursive;
-    bool mAddContactGroup;
+    QLabel *mMessageLabel = nullptr;
+    QRadioButton *mAllContactsButton = nullptr;
+    QRadioButton *mSelectedContactsButton = nullptr;
+    QRadioButton *mAddressBookContactsButton = nullptr;
+    Akonadi::CollectionComboBox *mAddressBookSelection = nullptr;
+    QCheckBox *mAddressBookSelectionRecursive = nullptr;
+    bool mAddContactGroup = false;
 };
 }
 #endif
