@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -66,7 +66,7 @@ protected:
     QList<QAction *> mExportActions;
     ImportExportAction mImportExportAction;
     Akonadi::Collection mDefaultCollection;
-    QItemSelectionModel *mItemSelectionModel;
+    QItemSelectionModel *mItemSelectionModel = nullptr;
 };
 }
 #endif // KADDRESSBOOKIMPORTEXPORTPLUGININTERFACE_H
